#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Wed 09/Sep/1992")
(component 0 "ROOTCONTEXT"
 (name "Dialog Box 4 Example")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (component 0 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 5 5
     This example is provided as an
     illustration "as is", and 
     Hewlett-Packard Company makes 
     no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 365 121)
     (extent 291 99)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 1 "TEXTDISPLAY"
   (name "Validated Input:")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (extent 154 0)
    )
    (detail
     (origin 716 423)
     (extent 228 35)
    )
    (active detail)
   )
  )
  (component 2 "NOTE"
   (name "To Operate:")
   (interface
   )
   (implementation
    (component text 7 5
     Click on "Run" and wait for
     the dialog box to pop up with
     a request to enter a number.
     
     You can enter both valid and
     invalid numbers and see the
     response.
    )
   )
   (views
    (icon
     (extent 110 0)
     (iconImage "notepad.icon")
    )
    (detail
     (origin 696 123)
     (extent 288 135)
     (editing enabled)
    )
    (active detail)
   )
  )
  (component 3 "CONTEXT"
   (name "Validating Dialog Box")
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "X")
     (lock constraints)
     (optional yes)
    )
   )
   (implementation
    (locked no)
    (trigMode deg)
    (component 0 "REPEATUNTILBREAK"
     (name "Until Break")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Continuous")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 35 288)
       (extent 110 64)
       (iconImage "loop.icon")
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "IFTHENELSE"
     (name "If/Then")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "A<1 OR A>10")
     )
     (views
      (icon
       (origin 611 378)
       (extent 78 25)
      )
      (detail
       (origin 301 318)
       (extent 149 64)
      )
      (terminals on)
      (active detail)
     )
    )
    (component 2 "CONTEXT"
     (name "Input Error")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (component 0 "NOTE"
       (name "Note Pad")
       (interface
       )
       (implementation
        (component text 1 9
         The number you entered is out of range.
        )
       )
       (views
        (icon
        )
        (detail
         (origin 598 680)
         (extent 364 33)
         (editing enabled)
        )
        (active detail)
       )
      )
      (component 1 "DELAY"
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Done")
         (tag "Done")
         (lock constraints)
        )
       )
       (implementation
        (component delay 5)
       )
       (views
        (icon
        )
        (detail
         (origin 595 763)
         (extent 130 34)
        )
        (active detail)
       )
      )
      (component 2 "EXITCONTEXT"
       (name "Exit UserObject")
       (interface
        (sequence in)
       )
       (implementation
       )
       (views
        (icon
         (origin 828 818)
         (extent 145 25)
        )
        (detail
        )
        (terminals on)
        (active icon)
       )
      )
      (component 3 "EXITCONTEXT"
       (name "Exit UserObject")
       (interface
        (sequence in)
       )
       (implementation
       )
       (views
        (icon
         (origin 678 818)
         (extent 145 25)
        )
        (detail
        )
        (terminals on)
        (active icon)
       )
      )
      (component 4 "CONFIRM"
       (name " OK ")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 811 742)
         (extent 58 37)
        )
        (detail
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
       (connect D4:1 D2:0)
       (connect D1:1 D3:0)
      )
      (ShowOnExecPanel
       (origin 229 322)
       (extent 397 147)
       (panel
        (origin 84 226)
        (extent 393 109)
        (widget 0 detail
         (title off)
         (origin 98 239)
         (extent 364 33)
         (editing enabled)
        )
        (widget 4 icon
         (title off)
         (origin 239 285)
         (extent 58 37)
        )
       )
      )
     )
     (views
      (icon
       (origin 545 348)
       (extent 110 25)
      )
      (detail
       (origin 568 637)
       (extent 425 227)
       (configuration
        (connect D4:1 D2:0
         (Point 871 760)
         (Point 900 760)
         (Point 900 815)
        )
        (connect D1:1 D3:0
         (Point 727 780)
         (Point 750 780)
         (Point 750 815)
        )
       )
       (stackingOrder 0 1 2 3 4)
      )
      (active icon)
     )
    )
    (component 3 "GATE"
     (name "Gate")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (tag "InData")
      )
      (output 1
       (type data)
       (name "X")
       (tag "OutData")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 517 468)
       (extent 46 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 4 "CONFIRM"
     (name " OK ")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 141 362)
       (extent 58 37)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 5 "CONSTANT"
     (name "Enter a number between 1 and 10")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (datum 11)
      )
      (component autoTrigger off)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (extent 289 0)
      )
      (detail
       (origin 39 466)
       (extent 363 28)
      )
      (active detail)
     )
    )
    (component 6 "EXITCONTEXT"
     (name "Exit UserObject")
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 468 518)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (component 7 "CONFIRM"
     (name "Cancel")
     (interface
      (sequence in)
      (sequence out)
      (output 1
       (type data)
       (name "Go")
       (lock name constraints)
      )
     )
     (implementation
     )
     (views
      (icon
       (origin 112 512)
       (extent 76 37)
      )
      (detail
       (origin 201 333)
       (extent 88 34)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 8 "EXITCONTEXT"
     (name "Exit UserObject")
     (interface
      (sequence in)
     )
     (implementation
     )
     (views
      (icon
       (origin 268 548)
       (extent 145 25)
      )
      (detail
      )
      (terminals on)
      (active icon)
     )
    )
    (configuration
     (connect D5:1 D1:1)
     (connect D1:1 D2:0)
     (connect D1:2 D3:0)
     (connect D5:1 D3:1)
     (connect D0:1 D4:0)
     (connect D4:1 D5:0)
     (connect D3:0 D6:0)
     (connect D7:1 D8:0)
     (connect D3:1 O1:1)
    )
    (ShowOnExecPanel
     (origin 214 210)
     (extent 424 197)
     (panel
      (origin 327 416)
      (extent 420 159)
      (widget 5 detail
       (title on)
       (origin 349 458)
       (extent 363 28)
      )
      (widget 4 icon
       (title off)
       (origin 368 506)
       (extent 58 37)
      )
      (widget 7 icon
       (title off)
       (origin 620 503)
       (extent 76 37)
      )
     )
    )
   )
   (views
    (icon
     (extent 199 0)
    )
    (detail
     (origin 14 272)
     (extent 652 317)
     (configuration
      (connect D5:1 D1:1
       (Point 404 480)
       (Point 420 480)
       (Point 420 410)
       (Point 240 410)
       (Point 240 350)
       (Point 258 350)
      )
      (connect D1:1 D2:0
       (Point 502 330)
       (Point 600 330)
       (Point 600 345)
      )
      (connect D1:2 D3:0
       (Point 502 370)
       (Point 520 370)
       (Point 520 390)
       (Point 540 390)
       (Point 540 465)
      )
      (connect D5:1 D3:1
       (Point 404 480)
       (Point 514 480)
      )
      (connect D0:1 D4:0
       (Point 147 320)
       (Point 170 320)
       (Point 170 359)
      )
      (connect D4:1 D5:0
       (Point 201 380)
       (Point 220 380)
       (Point 220 433)
      )
      (connect D3:0 D6:0
       (Point 540 495)
       (Point 540 515)
      )
      (connect D7:1 D8:0
       (Point 190 530)
       (Point 340 530)
       (Point 340 545)
      )
      (connect D3:1 O1:1
       (Point 565 480)
       (Point 580 480)
       (Point 580 440)
       (Point 663 440)
      )
     )
     (stackingOrder 0 1 2 3 4 5 6 7 8)
    )
    (active detail)
   )
  )
  (component 4 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (component 0 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 295 270)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 131 263)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About This Example")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (component 0 "CONFIRM"
       (name "DONE")
       (description 7 8
        This tiny "thread" begins running when the 
        enclosing UserObject is executed.  When the user
        acknowledges the OK/DONE button, there is nothing
        left to execute, so the thread ends.  Since there
        are not other threads running, the User Object
        is completed and will exit, removing the Show on
        Execute pop-up display.
       )
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 361 352)
         (extent 58 37)
        )
        (detail
         (origin 156 253)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (component 1 "NOTE"
       (name "Explanation")
       (interface
       )
       (implementation
        (component text 18 9
         PURPOSE:     This dialog box tests the user input for bounds.  If the test fails, the box
                      asking for input stays visible, and the user is told of the error by the
                      pop-up "error message" dialog box built in example dialog3.ex. 
         
         USER INPUT REQUIRED: Press "Run" and enter various valid and invalid inputs.  Note the
                      pop-up error when illegal values are entered.  You can either hit the OK each
                      time an error pops up, or wait 5 seconds for the error message to go away by
                      itself.
         
         EXPLANATION: The "Until Break" object drives the thread continuously until the user
                      inputs correct data or presses Cancel.  When the "OK" is pressed, the input
                      data is tested in the "If/Then" object.  If the data fails, the "Input
                      Error" pop-up message is displayed and another loop is executed.  If the
                      data passes the test, the "Gate" object is opened, the data is sent to the
                      UserObject's output data pin and "Exit UserObject" is done. The "Cancel"
                      button is still a "Confirm(OK)" object.   The "Input Error" object is the
                      Dialog Box 3 Example retitled and iconized.  
         
        )
       )
       (views
        (icon
         (origin 305 258)
         (extent 110 25)
        )
        (detail
         (origin 31 444)
         (extent 778 192)
         (editing enabled)
        )
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 24 75)
       (extent 872 344)
       (panel
        (origin 6 217)
        (extent 868 306)
        (widget 0 icon
         (title off)
         (origin 401 480)
         (extent 58 37)
        )
        (widget 1 detail
         (title off)
         (origin 19 228)
         (extent 841 242)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 332 358)
       (extent 217 25)
      )
      (detail
       (origin -23 170)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 0 1)
      )
      (active icon)
     )
    )
    (configuration
     (connect D1:1 D0:1)
     (connect D2:0 D1:1)
     (connect D0:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 408)
     (extent 110 25)
    )
    (panel
     (origin 21 132)
     (extent 319 77)
     (widget 1 icon
      (title off)
      (origin 123 145)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D1:1 D0:1
       (Point 247 282)
       (Point 292 282)
      )
      (connect D2:0 D1:1
       (Point 440 385)
       (Point 440 400)
       (Point 110 400)
       (Point 110 282)
       (Point 128 282)
      )
      (connect D0:1 D2:0
       (Point 343 272)
       (Point 440 272)
       (Point 440 355)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D3:1 D1:1)
  )
 )
 (views
  (panel
   (origin 0 67)
   (extent 901 433)
   (widget 0 detail
    (title on)
    (origin 579 106)
    (extent 291 99)
    (editing disabled)
   )
   (widget 2 detail
    (title on)
    (origin 275 106)
    (extent 288 135)
    (editing enabled)
   )
   (widget 4 panel
    (title on)
    (origin 24 107)
    (extent 237 100)
    (widget 1 icon
     (title off)
     (origin 72 130)
     (extent 114 39)
     (format button)
    )
   )
   (widget 1 detail
    (title on)
    (origin 279 333)
    (extent 285 38)
   )
  )
  (detail
   (origin 0 67)
   (extent 980 561)
   (configuration
    (connect D3:1 D1:1
     (Point 688 440)
     (Point 713 440)
    )
   )
   (stackingOrder 0 1 3 4 2)
  )
  (active panel)
  (active panel)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
  (delGlob yes)
 )
)
